@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-from flask_mail import Message
+from flask.ext.mail import Message
 from flaskup import mail
 
 
